@@ -13,6 +13,12 @@ import aws_cdk.aws_events
 import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.core
-__all__ = []
+import constructs
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sns", "1.33.0", __name__[0:-6], "aws-sns@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
